@@ -17,10 +17,61 @@ class witterCellRender(gtk.GenericCellRenderer):
 				'markup type',
 				'',
 				gobject.PARAM_READWRITE),
-			'background': (gobject.TYPE_STRING,
+			'backgroundt_r': (gobject.TYPE_INT,
 				'Background of the cell',
 				'The background of the cell',
-				'#00FF00',
+				0,
+				65535,
+				0,
+				gobject.PARAM_READWRITE),
+			'backgroundt_b': (gobject.TYPE_INT,
+				'Background of the cell',
+				'The background of the cell',
+				0,
+				65535,
+				0,
+				gobject.PARAM_READWRITE),
+			'backgroundt_g': (gobject.TYPE_INT,
+				'Background of the cell',
+				'The background of the cell',
+				0,
+				65535,
+				0,
+				gobject.PARAM_READWRITE),
+			'backgroundt_p': (gobject.TYPE_INT,
+				'Background of the cell',
+				'The background of the cell',
+				0,
+				65535,
+				0,
+				gobject.PARAM_READWRITE),
+			'backgroundb_r': (gobject.TYPE_INT,
+				'Background of the cell',
+				'The background of the cell',
+				0,
+				65535,
+				0,
+				gobject.PARAM_READWRITE),
+			'backgroundb_b': (gobject.TYPE_INT,
+				'Background of the cell',
+				'The background of the cell',
+				0,
+				65535,
+				0,
+				gobject.PARAM_READWRITE),
+			'backgroundb_g': (gobject.TYPE_INT,
+				'Background of the cell',
+				'The background of the cell',
+				0,
+				65535,
+				0,
+				gobject.PARAM_READWRITE),
+			'backgroundb_p': (gobject.TYPE_INT,
+				'Background of the cell',
+				'The background of the cell',
+				0,
+				65535,
+				0,
 				gobject.PARAM_READWRITE),
 			'timestamp': (gobject.TYPE_STRING,
 				'timestamp to be displayed',
@@ -99,15 +150,18 @@ class witterCellRender(gtk.GenericCellRenderer):
 		self.render_rect(cairo_context, x, y, widget.allocation.width - 8, h)
 
 		pat = cairo.LinearGradient(x, y, x, y + h)
-		color = gtk.gdk.color_parse("#6bd3ff")
+		color = gtk.gdk.Color(red=self.get_property('backgroundt_r'), green=self.get_property('backgroundt_g'), blue=self.get_property('backgroundt_b'), pixel=self.get_property('backgroundt_p'))
+		#color = gtk.gdk.color_parse(self.get_property('background_top'))
+		## #6bd3ff
 		pat.add_color_stop_rgba(
 							0.0,
 							self.get_cairo_color(color.red),
 							self.get_cairo_color(color.green),
 							self.get_cairo_color(color.blue),
 							1)
-
-		color = gtk.gdk.color_parse("#0075b5")
+		## #0075b5
+		#color = gtk.gdk.color_parse(self.get_property('background_bottom'))
+		color = gtk.gdk.Color(red=self.get_property('backgroundb_r'), green=self.get_property('backgroundb_g'), blue=self.get_property('backgroundb_b'), pixel=self.get_property('backgroundb_p'))
 		pat.add_color_stop_rgb(
 							1.0,
 							self.get_cairo_color(color.red),
@@ -163,7 +217,8 @@ class witterCellRender(gtk.GenericCellRenderer):
 			layout = cairo_context.create_layout()
 			cairo_context.set_source_rgba(1, 1, 1, 1)
 			font = pango.FontDescription("Sans")
-			font.set_size(pango.SCALE * (self.get_property('font_size') - 6))
+			font.set_size(pango.SCALE * (self.get_property('font_size') - 2))
+			#font.set_size(pango.SCALE * (12))
 			font.set_style(pango.STYLE_NORMAL)
 			font.set_weight(pango.WEIGHT_BOLD)
 			layout.set_font_description(font)
@@ -178,7 +233,8 @@ class witterCellRender(gtk.GenericCellRenderer):
 		cairo_context.set_source_rgba(1, 1, 1, 1)
 		cairo_context.select_font_face("Georgia",
                 cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_BOLD)
-		cairo_context.set_font_size(self.get_property('font_size') - 5)
+		#cairo_context.set_font_size(self.get_property('font_size') - 5)
+		cairo_context.set_font_size(12)
 		ts_x_bearing, ts_y_bearing, ts_width, ts_height = cairo_context.text_extents("From " + str(self.get_property('source')) + " at " + str(self.get_property('timestamp')))[:4]
 		#position in the bottom right, in set by the width of the timestamp, and a little padding
 		cairo_context.move_to(x + (w - (ts_width + 10)), y + (h - 5))
@@ -234,22 +290,22 @@ class witterCellRender(gtk.GenericCellRenderer):
 		inkRect, logicalRect = layout.get_pixel_extents()
 		tweet_x, tweet_y, width, tweet_h = logicalRect
 
-		if ((self.get_property('replyto') != "") & (self.get_property('replyto') != None)):
+		#if ((self.get_property('replyto') != "") & (self.get_property('replyto') != None)):
 			#process any retweet text
-			layout2 = cairo_context.create_layout()
-			font = pango.FontDescription("Sans")
-			font.set_size(pango.SCALE * (self.get_property('font_size') - 6))
-			font.set_style(pango.STYLE_NORMAL)
-			font.set_weight(pango.WEIGHT_BOLD)
-			layout2.set_font_description(font)
-			layout2.set_wrap(pango.WRAP_WORD)
-			layout2.set_width(pango.SCALE * 780)
-			#set position under the main tweet text
-			layout2.set_text(self.get_property('replyto'))
-			inkRect2, logicalRect2 = layout2.get_pixel_extents()
-			reply_x, reply_y, reply_width, reply_tweet_h = logicalRect2
-
-			tweet_h = tweet_h + reply_tweet_h
+			#layout2 = cairo_context.create_layout()
+			#font = pango.FontDescription("Sans")
+			#font.set_size(pango.SCALE * (self.get_property('font_size') - 6))
+			#font.set_style(pango.STYLE_NORMAL)
+			#font.set_weight(pango.WEIGHT_BOLD)
+			#layout2.set_font_description(font)
+			#layout2.set_wrap(pango.WRAP_WORD)
+			#layout2.set_width(pango.SCALE * 780)
+			##set position under the main tweet text
+			#layout2.set_text(self.get_property('replyto'))
+			#inkRect2, logicalRect2 = layout2.get_pixel_extents()
+			#reply_x, reply_y, reply_width, reply_tweet_h = logicalRect2
+			#print reply_tweet_h
+		#	tweet_h = tweet_h + 15
 		#figure out how many times we need to split the string to fit on the screen
 		#divide_text = width / (widget.allocation.width - 8)
 		#round the value to an int and plus 1
